<?php

Class Cloudns_Helper {
	
	public function redirect ($url) {
		header("Location: {$url}");
		exit;
	}
	
	/**
	 * Get a parameter from $_POST variable
	 * @param string $param
	 * @return string 
	 */
	public static function getPost ($param, $default='') {
		if (isset($_POST[$param])) {
			return $_POST[$param];
		}
		return $default;
	}

	/**
	 * Get a parameter  from $_GET variable
	 * @param string $param
	 * @param mixed $default
	 * @return string 
	 */
	public static function getGet ($param, $default='') {
		if (isset($_GET[$param])) {
			return $_GET[$param];
		}
		return $default;
	}
	
	/**
	 * Get a parameter from $_REQUEST variable
	 * @param string $param
	 * @return string 
	 */
	public static function getRequest ($param, $default='') {
		if (isset($_REQUEST[$param])) {
			return $_REQUEST[$param];
		}
		return $default;
	}
	
	/**
	 * 
	 * @param string $zone_name
	 * @param int $shortLenght Maximum lenght of the string to be shortned if above
	 * @return type
	 */
	public function shortenLongName($zone_name, $shortLenght=55) {
		$name = $this->getUnicodeName($zone_name);
		return $this->shortenLongString($name, $shortLenght);
	}
	
	/**
	 * Checks if a sting is longer than $shortLenght symbols and make it shorter to fit on the row.
	 * @param int $string
	 * @param int $shortLenght Maximum lenght of the string to be shortned if above
	 * @return array
	 */
	public function shortenLongString ($string, $shortLenght=55) {
		
		$domainName = array();
		
		$shortName = $string;
		if (mb_strlen($string) > $shortLenght) {
			$shortName = mb_substr($string, 0, $shortLenght, 'UTF-8');
		}
		
		$domainName['title'] = $string;
		$domainName['shortName'] = $shortName;

		return $domainName;
	}
	
	
	/**
	 * Get real ASCII name
	 * @param string $name
	 * @return string
	 */
	public function getAsciiName ($name) {
		if (function_exists('idn_to_ascii')) {
			$convertedName = @idn_to_ascii($name);
		} else {
			$convertedName = $name;
		}

		if (empty($convertedName) && !empty($name)) {
			return $name;
		}
		return $convertedName;
	}

	/**
	 * Get native IDN name in Unicode, readable
	 * @param string $name
	 * @return string
	 */
	public function getUnicodeName ($name) {
		if (function_exists('idn_to_utf8')) {
			return idn_to_utf8($name);
		}
		
		return $name;
	}
	
	/**
	 * Convirts seconds in minutes, hours, days or weeks
	 * @param int $seconds
	 * @return string
	 */
	public function convertSeconds ($seconds) {
		if ($seconds < 3600) {
			return round($seconds / 60).'m';
		} else if ($seconds < 86400) {
			return round($seconds / 3600).'h';
		} else if ($seconds < 604800) {
			return round($seconds / 86400).'d';
		} else if ($seconds <= 2592000) {
			return round($seconds / 604800).'w';
		} else {
			return round($seconds / 604800).'d';
		}
	}
}

